@@ -4,7 +4,7 @@ Created on 26 Jan 2021
 @author: jacklok
 '''
 from trexanalytics.conf import UPSTREAM_UPDATED_DATETIME_FIELD_NAME, MERCHANT_DATASET, SYSTEM_DATASET
-import uuid, logging
+import uuid, logging  
 from trexmodel.models.datastore.analytic_models import UpstreamData
 from trexanalytics.bigquery_table_template_config import REGISTERED_CUSTOMER_TEMPLATE, REGISTERED_MERCHANT_TEMPLATE, MERCHANT_REGISTERED_CUSTOMER_TEMPLATE,\
     CUSTOMER_TRANSACTION_TEMPLATE, MERCHANT_CUSTOMER_REWARD_TEMPLATE,\
@@ -15,7 +15,7 @@ from trexmodel.models.datastore.transaction_models import CustomerTransactionWit
     CustomerTransactionWithPrepaidDetails
 from trexanalytics import conf
 from trexmodel.models.datastore.ndb_models import convert_to_serializable_value
-from trexmodel import program_conf
+from trexmodel import program_conf 
 from trexmodel.models.datastore.redeem_models import CustomerRedeemedItemUpstream
 
 __REGISTERED_MERCHANT_TEMPLATE_UPSTREAM_SCHEMA = { 
@@ -89,7 +89,6 @@ __CUSTOMER_PREPAID_DATA_TEMPLATE_UPSTREAM_SCHEMA = {
                                             "TransactDateTime"      : 'transact_datetime',
                                             "TopupAmount"           : 'topup_amount',
                                             "PrepaidAmount"         : 'prepaid_amount',
-                                            "ExpiryDate"            : 'expiry_date',
                                             "TopupDateTime"         : 'topup_datetime',
                                             "Reverted"              : 'is_revert',
                                             "RevertedDateTime"      : 'reverted_datetime',
@@ -205,6 +204,20 @@ def create_merchant_customer_reward_upstream_for_merchant(transaction_details, r
     __create_upstream(transaction_details_with_reward_details, MERCHANT_CUSTOMER_REWARD_TEMPLATE, MERCHANT_DATASET, final_table_name, 
                       streamed_datetime=streamed_datetime, Reverted=False, RevertedDateTime=None)
     
+def create_merchant_customer_prepaid_upstream_for_merchant(transaction_details, prepaid_details, streamed_datetime=None):
+    if streamed_datetime is None:
+        streamed_datetime = datetime.utcnow()
+    
+    table_name          = MERCHANT_CUSTOMER_PREPAID_TEMPLATE
+    merchant_acct       = transaction_details.transact_merchant_acct
+    account_code        = merchant_acct.account_code.replace('-','')
+    final_table_name    = '{}_{}_{}'.format(table_name, account_code, streamed_datetime.strftime('%Y%m%d'))
+    
+    transaction_details_with_prepaid_details = CustomerTransactionWithPrepaidDetails(transaction_details, prepaid_details)
+    
+    __create_upstream(transaction_details_with_prepaid_details, MERCHANT_CUSTOMER_PREPAID_TEMPLATE, MERCHANT_DATASET, final_table_name, 
+                      streamed_datetime=streamed_datetime, Reverted=False, RevertedDateTime=None)    
+    
 def create_merchant_customer_reward_reverted_upstream_for_merchant(transaction_details, reward_details, reverted_datetime):
     partition_datetime = transaction_details.transact_datetime
     
@@ -256,7 +269,7 @@ def create_merchant_customer_redemption_upstream_for_merchant(customer_redemptio
     redeemed_datetime   = customer_redemption.redeemed_datetime
     
     for reward_format, redemption_details in customer_redemption.redeemed_summary.items():
-        if reward_format in (program_conf.REWARD_FORMAT_POINT, program_conf.REWARD_FORMAT_STAMP):
+        if reward_format in (program_conf.REWARD_FORMAT_POINT, program_conf.REWARD_FORMAT_STAMP, program_conf.REWARD_FORMAT_PREPAID):
             upstream_data_list.append(CustomerRedeemedItemUpstream(
                                         customer_key        = customer_key,
                                         merchant_key        = merchant_key,
