@@ -60,14 +60,11 @@ STREAM_DATA_PAGE_SIZE                               = 100
 SYSTEM_DATASET                                      = os.environ.get('SYSTEM_DATASET')
 MERCHANT_DATASET                                    = os.environ.get('MERCHANT_DATASET')
 
-ANALYTICS_TASK_GCLOUD_PROJECT_ID                    = os.environ.get('ANALYTICS_TASK_GCLOUD_PROJECT_ID')
-ANALYTICS_TASK_GCLOUD_LOCATION                      = os.environ.get('ANALYTICS_TASK_GCLOUD_LOCATION')
-ANALYTICS_TASK_SERVICE_ACCOUNT_KEY_FILEPATH         = os.environ.get('ANALYTICS_TASK_SERVICE_ACCOUNT_KEY')
-ANALYTICS_TASK_SERVICE_CREDENTIAL_PATH              = os.path.abspath(os.path.dirname(config_path.__file__)) + '/' + ANALYTICS_TASK_SERVICE_ACCOUNT_KEY_FILEPATH
-ANALYTICS_TASK_SERVICE_ACCOUNT_EMAIL                = os.environ.get('ANALYTICS_TASK_SERVICE_ACCOUNT_EMAIL')
-
-SERVER_DATETIME_GMT                                 = os.environ.get('SERVER_DATETIME_GMT')
-
+SYSTEM_TASK_GCLOUD_PROJECT_ID                    = os.environ.get('SYSTEM_TASK_GCLOUD_PROJECT_ID')
+SYSTEM_TASK_GCLOUD_LOCATION                      = os.environ.get('SYSTEM_TASK_GCLOUD_LOCATION')
+SYSTEM_TASK_SERVICE_ACCOUNT_KEY_FILEPATH         = os.environ.get('SYSTEM_TASK_SERVICE_ACCOUNT_KEY')
+SYSTEM_TASK_SERVICE_CREDENTIAL_PATH              = os.path.abspath(os.path.dirname(config_path.__file__)) + '/' + SYSTEM_TASK_SERVICE_ACCOUNT_KEY_FILEPATH
+SYSTEM_TASK_SERVICE_ACCOUNT_EMAIL                = os.environ.get('SYSTEM_TASK_SERVICE_ACCOUNT_EMAIL')
 
 UPSTREAM_UPDATED_DATETIME_FIELD_NAME                = 'UpdatedDateTime'
 
