@@ -7,11 +7,12 @@ from flask import Blueprint
 import logging
 from trexlib.utils.google.bigquery_util import process_job_result_into_category_and_count, execute_query
 from trexanalytics.controllers.bigquery.query_base_routes import CategoryAndCountQueryBaseResource,\
-    QueryBaseResource
+    QueryBaseResource, BaseResource
 from flask_restful import Api
 from trexanalytics.conf import BIGQUERY_GCLOUD_PROJECT_ID, SYSTEM_DATASET, MERCHANT_DATASET
 
 
+
 customer_analytics_data_bp = Blueprint('customer_analytics_data_bp', __name__,
                                  template_folder='templates',
                                  static_folder='static',
@@ -64,9 +65,9 @@ class QueryMerchantCategoryDataByDateRangeBaseResource(CategoryAndCountQueryBase
         
         account_code = account_code.replace('-','')
         
-        logger.debug('account_code=%s', account_code)
-        logger.debug('date_range_from=%s', date_range_from)
-        logger.debug('date_range_to=%s', date_range_to)
+        logger.info('account_code=%s', account_code)
+        logger.info('date_range_from=%s', date_range_from)
+        logger.info('date_range_to=%s', date_range_to)
         
         condition = ''
         
@@ -88,9 +89,9 @@ class QueryMerchantCustomDataByDateRangeBaseResource(QueryBaseResource):
         
         account_code = account_code.replace('-','')
         
-        logger.debug('account_code=%s', account_code)
-        logger.debug('date_range_from=%s', date_range_from)
-        logger.debug('date_range_to=%s', date_range_to)
+        logger.info('account_code=%s', account_code)
+        logger.info('date_range_from=%s', date_range_from)
+        logger.info('date_range_to=%s', date_range_to)
         
         condition = ''
         
@@ -121,8 +122,6 @@ class QueryMerchantCustomerGrowthByYearMonth(QueryMerchantCustomDataByDateRangeB
             ) GROUP BY year_month            
             '''.format(project_id=BIGQUERY_GCLOUD_PROJECT_ID, dataset_name=MERCHANT_DATASET, where_condition=condition, account_code=account_code)    
             
-        logger.info('execute_all_registered_customer_by_year_month: query=%s', query)
-    
         return query 
     
     
@@ -140,8 +139,6 @@ class QueryMerchantCustomerCountByDateRange(QueryMerchantCustomDataByDateRangeBa
                         
             '''.format(project_id=BIGQUERY_GCLOUD_PROJECT_ID, dataset_name=MERCHANT_DATASET, where_condition=condition, account_code=account_code)    
             
-        logger.debug('QueryMerchantCustomerCountByDateRange: query=%s', query)
-    
         return query 
     
     def process_query_result(self, job_result_rows):
@@ -163,7 +160,7 @@ class QueryMerchantCustomerGenderByDateRange(QueryMerchantCustomDataByDateRangeB
                 (
                 
                 SELECT
-                  checking.Key, checking.CustomerKey, checking.UpdatedDateTime, checking.Gender as gender
+                  DISTINCT checking.Key, checking.CustomerKey, checking.UpdatedDateTime, checking.Gender as gender
                 FROM
                   (
                   SELECT
@@ -193,9 +190,6 @@ class QueryMerchantCustomerGenderByDateRange(QueryMerchantCustomDataByDateRangeB
                         
             '''.format(project_id=BIGQUERY_GCLOUD_PROJECT_ID, dataset_name=MERCHANT_DATASET, where_condition=condition, account_code=account_code)    
             
-        logger.debug('QueryMerchantCustomerCountByDateRange: project_id=%s', BIGQUERY_GCLOUD_PROJECT_ID)
-        logger.debug('QueryMerchantCustomerCountByDateRange: query=%s', query)
-    
         return query 
     
     def process_query_result(self, job_result_rows):
@@ -233,7 +227,7 @@ class QueryMerchantCustomerAgeGroupByDateRange(QueryMerchantCustomDataByDateRang
                                 FROM(
             
                                 SELECT
-                                  checking.Key, checking.CustomerKey, checking.UpdatedDateTime, checking.DOB as DOB
+                                  DISTINCT checking.Key, checking.CustomerKey, checking.UpdatedDateTime, checking.DOB as DOB
                                 FROM
                                   (
                                   SELECT
@@ -304,8 +298,15 @@ def execute_all_registered_customer_by_year_month(bg_client, project_id, dataset
 def process_all_registered_customer_by_year_month(job_result_rows):
     return process_job_result_into_category_and_count(job_result_rows)
 
+
+@customer_analytics_data_bp.route('/')
+def customer_data_analytics():
+    logger.debug('This is default path for this blueprint')
+    return 'Customer Data Analytics', 200
+
 query_customer_data_api.add_resource(QueryAllCustomerGrowthByYearMonth,         '/all-cust-growth-by-year-month')
 query_customer_data_api.add_resource(QueryMerchantCustomerGrowthByYearMonth,    '/merchant-cust-growth-by-year-month')
 query_customer_data_api.add_resource(QueryMerchantCustomerCountByDateRange,     '/merchant-cust-count-by-date-range')
 query_customer_data_api.add_resource(QueryMerchantCustomerGenderByDateRange,    '/merchant-cust-gender-by-date-range')
 query_customer_data_api.add_resource(QueryMerchantCustomerAgeGroupByDateRange,  '/merchant-cust-age-group-by-date-range')
+query_customer_data_api.add_resource(BaseResource,  '/base')
