@@ -188,7 +188,7 @@ class InitImportMerchantRegisteredCustomer(InitImportDataBaseResource):
         return 'import-customer'
     
     def get_data_payload(self):
-        content             = request.json
+        content             = request.args.to_dict() or request.json or {}
         merchant_acct_key   = content.get('merchant_acct_key')
         
         return {
@@ -220,7 +220,7 @@ class ImportMerchantRegisteredCustomer(ImportDataBaseResource):
         return 'import-customer'
     
     def get_data_payload(self):
-        content             = request.json
+        content             = request.args.to_dict() or request.json or {}
         merchant_acct_key   = content.get('merchant_acct_key')
         
         return {
